
import { useState } from "react";
import { Send } from "lucide-react";
import { Button } from "@/components/ui/button";
import { Input } from "@/components/ui/input";
import { Card } from "@/components/ui/card";
import { toast } from "sonner";
import { supabase } from "@/lib/supabase";

export function MessageComposer() {
  const [message, setMessage] = useState("");
  const [phoneNumber, setPhoneNumber] = useState("");
  const [isSending, setIsSending] = useState(false);

  const handleSend = async () => {
    if (!message.trim() || !phoneNumber.trim()) {
      toast.error("Please enter both phone number and message");
      return;
    }

    const formattedPhoneNumber = phoneNumber.startsWith('+1') ? phoneNumber : `+1${phoneNumber}`;
    
    console.log('Attempting to store message:', { phoneNumber: formattedPhoneNumber, message });
    setIsSending(true);
    
    try {
      // Store the message in Supabase
      const { data, error } = await supabase
        .from('messages')
        .insert([
          { 
            phone_number: formattedPhoneNumber,
            message: message 
          }
        ])
        .select();

      if (error) {
        console.error('Supabase insert error:', error);
        throw error;
      }

      console.log('Message stored successfully:', data);
      toast.success("Message stored successfully!");
      setMessage("");
      setPhoneNumber("");
    } catch (error: any) {
      console.error('Detailed error:', error);
      toast.error(`Failed to store message: ${error.message || 'Please try again'}`);
    } finally {
      setIsSending(false);
    }
  };

  return (
    <Card className="p-6 animate-fadeIn">
      <div className="space-y-4">
        <h2 className="text-2xl font-semibold tracking-tight">Send Message</h2>
        <div className="space-y-4">
          <div className="space-y-2">
            <label
              htmlFor="phone"
              className="text-sm font-medium leading-none peer-disabled:cursor-not-allowed peer-disabled:opacity-70"
            >
              Phone Number
            </label>
            <Input
              id="phone"
              placeholder="Enter phone number... (e.g. +13109228324)"
              value={phoneNumber}
              onChange={(e) => setPhoneNumber(e.target.value)}
              className="w-full"
              disabled={isSending}
            />
          </div>
          <div className="space-y-2">
            <label
              htmlFor="message"
              className="text-sm font-medium leading-none peer-disabled:cursor-not-allowed peer-disabled:opacity-70"
            >
              Message
            </label>
            <Input
              id="message"
              placeholder="Type your message..."
              value={message}
              onChange={(e) => setMessage(e.target.value)}
              className="w-full"
              disabled={isSending}
            />
          </div>
          <Button
            onClick={handleSend}
            className="w-full group hover:shadow-md transition-all"
            disabled={isSending}
          >
            <Send className="mr-2 h-4 w-4 group-hover:scale-110 transition-transform" />
            {isSending ? "Sending..." : "Send Message"}
          </Button>
        </div>
      </div>
    </Card>
  );
}
